@@ -8,7 +8,7 @@ DialogNewWord::DialogNewWord(QWidget *parent) :
     ui->setupUi(this);
 
     ui->lineEdit->setEnabled(false);
-    ui->kb->setStandalone(true);
+    //ui->kb->setScope(true);
     m_btOk = ui->btOk;
     //m_kb = new kb_Qwerty(this,true);
     m_kb = ui->kb;
