@@ -19,6 +19,7 @@
 
 #include "dialogsettings.h"
 #include "ui_dialogsettings.h"
+#include "dialogabout.h"
 #include <QSettings>
 #include <QDir>
 #include <QDesktopServices>
@@ -32,6 +33,7 @@ DialogSettings::DialogSettings(QWidget *parent) :
 
     connect(ui->btSave,SIGNAL(clicked()),this,SLOT(closeOptions()));
     connect(ui->btDonate,SIGNAL(clicked()),this,SLOT(donate()));
+    connect(ui->btAbout,SIGNAL(clicked()),this,SLOT(about()));
     QSettings settings;
 
     //Populate list of available languages
@@ -69,6 +71,12 @@ DialogSettings::DialogSettings(QWidget *parent) :
 
     //Pref Portrait Kb
     ui->cbPrefPortraitKb->setCurrentIndex(settings.value(Core::PREF_PORTRAIT_KB,1).toInt());
+
+    //Qwerty Layout
+    ui->cbQwertyLayout->setCurrentIndex(settings.value(Core::SETTING_QWERTY_LAYOUT,0).toInt());
+
+    //Label color
+    ui->cbLabelColor->setCurrentIndex(settings.value(Core::SETTING_LABEL_COLOR,0).toInt());
 }
 
 DialogSettings::~DialogSettings()
@@ -109,6 +117,12 @@ void DialogSettings::closeOptions()
     //Pref Portrait Kb
     settings.setValue(Core::PREF_PORTRAIT_KB,ui->cbPrefPortraitKb->currentIndex());
 
+    //Qwerty Layout
+    settings.setValue(Core::SETTING_QWERTY_LAYOUT,ui->cbQwertyLayout->currentIndex());
+
+    //Label color
+    settings.setValue(Core::SETTING_LABEL_COLOR,ui->cbLabelColor->currentIndex());
+
     close();
 
     emit settingsChanged(isLanguageChanged);
@@ -116,5 +130,14 @@ void DialogSettings::closeOptions()
 
 void DialogSettings::donate()
 {
+    closeOptions();
+
     QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=V353RBQ6TATN6&lc=GB"));
 }
+
+void DialogSettings::about()
+{
+    DialogAbout *about = new DialogAbout(this);
+    about->setAttribute(Qt::WA_DeleteOnClose);
+    about->showMaximized();
+}
