@@ -50,7 +50,7 @@ public Q_SLOTS: // METHODS
     void surroundRequest(const QString &text);
 
 public slots:
-    void insertNewWord();
+    void insertNewWord(bool=false);
     void openAboutDialog();
     void donate();
     void openOptionDialog();
@@ -69,6 +69,7 @@ private:
     bool m_bDictionaryUpdated;
     bool m_bStandalone;
     QString m_sCurrOrientation;
+    bool m_bSymbolInserted;
 
 private slots:
     void newWordInserted();
