@@ -32,22 +32,23 @@ class kb_Qwerty : public Keyboard
     Q_OBJECT
 
 public:
-    explicit kb_Qwerty(QWidget *parent = 0, bool bStandalone = false);
+    explicit kb_Qwerty(QWidget *parent = 0/*, bool bStandalone = false, bool bSymbol = false*/);
     ~kb_Qwerty();
-    void setStandalone(bool bStandalone);
+    void setScope(bool bStandalone, bool bOnlySymbol = false);
+    void loadLayout(Core::QwertyLayout layout=Core::noneLayout);
 
 
 private:
     Ui::kb_Qwerty *ui;
-    int m_nActiveModifiers;
-    void setButtonsLabel();
+//    int m_nActiveModifiers;
+    //void setButtonsLabel();
 
 public slots:
     void directInputClicked();
            // void settingsChanged(int);
 
 private slots:
-    void maiuscClicked(/*int nForceCheck = 0*/);
+    //void maiuscClicked(/*int nForceCheck = 0*/);
     void symClicked();
     void newLineClicked();
     void spaceClicked();
