@@ -37,15 +37,17 @@ public:
     ~KeyboardManager();
     void enableQwerty();
     void enableAlfanum();
+    void loadQwertyLayout(Core::QwertyLayout);
+    void setLabelColor(Core::LabelColor color);
 
 public slots:
     void settingsChanged(int);
 //    void orientationChanged(QString);
-    void processInput(QString, Core::Keyboards);
+    void processInput(QString, Core::Keyboards,bool);
 
 signals:
     void inputStyleChanged(int);
-    void input(QString, Core::Keyboards);
+    void input(QString, Core::Keyboards,bool);
 
 private:
     Ui::KeyboardManager *ui;
