@@ -30,14 +30,14 @@ LayoutManager::LayoutManager(QWidget *parent) :
     ui->setupUi(this);
 
     //connect(ui->kbHorizontal,SIGNAL(input(QString, Core::Keyboards)),ui->textWidget,SLOT(processInput(QString, Core::Keyboards)));
-    connect(ui->kbVertical,SIGNAL(input(QString, Core::Keyboards)),ui->textWidget,SLOT(processInput(QString, Core::Keyboards)));
+    connect(ui->kbVertical,SIGNAL(input(QString, Core::Keyboards,bool)),ui->textWidget,SLOT(processInput(QString, Core::Keyboards,bool)));
     //connect(ui->kbHorizontal,SIGNAL(inputStyleChanged(int)),ui->textWidget,SLOT(settingsChanged(int)));
     connect(ui->kbVertical,SIGNAL(inputStyleChanged(int)),ui->textWidget,SLOT(settingsChanged(int)));
 
     connect(ui->kbVertical,SIGNAL(inputStyleChanged(int)),qobject_cast<FastSMSWidget *> (parentWidget()),SLOT(actionMenu(int)));
 
     //TODO: only test purpose
-    ui->kbHorizontal->hide();
+    //ui->kbHorizontal->hide();
 }
 
 LayoutManager::~LayoutManager()
@@ -60,5 +60,16 @@ void LayoutManager::enableAlfanum()
     ui->kbVertical->enableAlfanum();
 }
 
+void LayoutManager::loadQwertyLayout(Core::QwertyLayout layout)
+{
+    ui->kbVertical->loadQwertyLayout(layout);
+}
+
+void LayoutManager::setLabelColor(Core::LabelColor color)
+{
+    ui->kbVertical->setLabelColor(color);
+}
+
+
 
 
