@@ -38,6 +38,9 @@ public:
     TextProcessor* getTextProcessor();
     void enableQwerty();
     void enableAlfanum();
+    void loadQwertyLayout(Core::QwertyLayout);
+    void setLabelColor(Core::LabelColor color);
+
 
 private:
     Ui::LayoutManager *ui;
