@@ -30,7 +30,7 @@ class SettingsMenu : public QMenu
     Q_OBJECT
 public:
     static SettingsMenu* instance(QWidget *parent = 0);
-    enum inputStyle {AutoCapitalize, UpperCase, LowerCase, DigitOnly, FastWriteOff, FastWriteOn, QwertyOn, AlfanumOn, Options, NewWord};
+    enum inputStyle {AutoCapitalize, UpperCase, LowerCase, DigitOnly, FastWriteOff, FastWriteOn, QwertyOn, AlfanumOn, Options, NewWord, Symbols};
     ~SettingsMenu();
     void updateMenu(int);
 
@@ -46,6 +46,7 @@ private:
     static void drop();
     void qwertyEnabled();
     void alfanumEnabled();
+    inputStyle m_nActiveStyle;
 
     QAction *m_aEnableQwerty;
     QAction *m_aEnableAlfanum;
@@ -56,6 +57,7 @@ private:
     QAction *m_aDigit;
     QAction *m_aOptions;
     QAction *m_aNewWord;
+    QAction *m_aSymbols;
 
 };
 
